@@ -1,7 +1,13 @@
+"""
+Pagination Generic Class
+"""
 from flask_marshmallow import Marshmallow
 
 
 class PaginationSchema:
+    """
+    Pagination Class
+    """
     schema_object = None
     ma = Marshmallow()
 
@@ -12,5 +18,11 @@ class PaginationSchema:
         self.pagination_sub_class = self.PaginationSchemaSubClass()
 
     class PaginationSchemaSubClass(ma.SQLAlchemyAutoSchema):
+        """
+        Pagination Schema Data
+        """
         class Meta:
+            """
+            Meta Class
+            """
             fields = ('has_prev', 'has_next', 'next_num', 'page', 'pages', 'per_page', 'prev_num', 'total', 'items')
