@@ -14,6 +14,7 @@ class JsonEncodeDict(TypeDecorator, ABC):
     Enables JSON storage by encoding and decoding on the fly.
     """
     impl = Text
+    cache_ok = True
 
     def process_bind_param(self, value, dialect):
         """
@@ -63,4 +64,4 @@ def generic_get_serialize_data(schema_object, query):
     :param query:
     :return:
     """
-    return schema_object().dump(query)
+    return schema_object.dump(query)
