@@ -117,5 +117,7 @@ class ViewGeneralMethods:
         :return:
         """
         model_object = self.db.get_or_404(model, object_id)
-        model_object[field] = not model_object[field]
+        model.query.filter_by(id=object_id).update({field: not getattr(model_object, field)})
         self.db.session.commit()
+        return prepare_json_response(
+            f'{model.__name__} field {field} updated to {getattr(model_object, field)} successfully!')
